@@ -20,16 +20,16 @@ pub(crate) fn impl_macro_sql(target_fn: &ItemFn, args: &AttributeArgs) -> TokenS
     let is_async = target_fn.sig.asyncness.is_some();
     if !is_async {
         panic!(
-            "[rbaits] 'fn {}({})' must be  async fn! ",
+            "[rbaits] #[crud_table] 'fn {}({})' must be  async fn! ",
             func_name_ident, func_args_stream
         );
     }
     let mut call_method = quote! {};
     let is_fetch = is_fetch_sql(&sql);
     if is_fetch {
-        call_method = quote! {fetch_prepare};
+        call_method = quote! {fetch};
     } else {
-        call_method = quote! {exec_prepare};
+        call_method = quote! {exec};
     }
     //check use page method
     let mut page_req_str = String::new();
@@ -43,15 +43,15 @@ pub(crate) fn impl_macro_sql(target_fn: &ItemFn, args: &AttributeArgs) -> TokenS
         call_method = quote! {fetch_page};
     }
     //append all args
-    let (sql_args_gen, context_id_ident) =
-        filter_args_context_id(&rbatis_name, &get_fn_args(target_fn), &[page_req_str]);
+    let sql_args_gen = filter_args_context_id(&rbatis_name, &get_fn_args(target_fn), &[page_req_str]);
     //gen rust code templete
     let gen_token_temple = quote! {
        pub async fn #func_name_ident(#func_args_stream) -> #return_ty{
            let mut rb_args =vec![];
            #sql_args_gen
            #fn_body
-           return #rbatis_ident.#call_method(#context_id_ident,&#sql_ident,&rb_args #page_req).await;
+           use rbatis::executor::{Executor,ExecutorMut};
+           return #rbatis_ident.#call_method(&#sql_ident,&rb_args #page_req).await;
        }
     };
     return gen_token_temple.into();
@@ -61,19 +61,14 @@ fn filter_args_context_id(
     rbatis_name: &str,
     fn_arg_name_vec: &Vec<String>,
     skip_names: &[String],
-) -> (proc_macro2::TokenStream, proc_macro2::TokenStream) {
+) -> proc_macro2::TokenStream {
     let mut sql_args_gen = quote! {};
-    let mut context_id_ident = quote! {""};
     for item in fn_arg_name_vec {
         let item_ident = Ident::new(&item, Span::call_site());
         let item_ident_name = item_ident.to_string();
         if item.eq(&rbatis_name) {
             continue;
         }
-        if item.eq("ctx_id") || item.eq("context_id") || item.eq("tx_id") {
-            context_id_ident = item_ident.to_token_stream();
-            continue;
-        }
         let mut do_continue = false;
         for x in skip_names {
             if x.eq(&item_ident_name) {
@@ -89,5 +84,5 @@ fn filter_args_context_id(
              rb_args.push(serde_json::json!(#item_ident));
         };
     }
-    (sql_args_gen, context_id_ident)
+    sql_args_gen
 }
